module.exports = defineTest({
	description: 'imports a dependency from the same module'
});
